/*
 * Created on 29/ago/2010
 *
 * Copyright 2010 by Andrea Vacondio (andrea.vacondio@gmail.com).
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 */
package org.sejda.core.support.io;

import org.sejda.core.support.io.model.PopulatedFileOutput;
import org.sejda.model.exception.TaskIOException;
import org.sejda.model.output.FileOutput;
import org.sejda.model.output.OutputType;
import org.sejda.model.output.TaskOutput;

/**
 * Provides support methods to write output for those tasks writing a single output. When the task requires, it can flush to the output destination a single temporary file
 * generated by the task itself.
 * 
 * <pre>
 * {@code
 * SingleOutputWriterSupport outputWriter = new SingleOutputWriterSupport();
 * PopulatedFileOutput singleOut = file(tmpFile).name("newName");
 * AbstractPdfOutput output = ...
 * boolean overwrite = ...
 * outputWriter.flushSingleOutput(singleOut, output, overwrite);
 * }
 * </pre>
 * 
 * @author Andrea Vacondio
 * 
 */
class DefaultSingleOutputWriter extends BaseOutputWriter implements SingleOutputWriter {

    public void flushSingleOutput(PopulatedFileOutput fileOutput, TaskOutput output, boolean overwrite)
            throws TaskIOException {
        add(fileOutput);
        try {
            if (OutputType.FILE_OUTPUT.equals(output.getOutputType())) {
                write(new OutputDestination(output, overwrite));
            } else {
                writeToNonFileDestination(output, overwrite);
            }
        } finally {
            clear();
        }
    }

}
